@@ -33,6 +33,13 @@ impl SkimString for Vec<Node> {
     fn to_skim_string(self, label_whitelist: Option<Vec<String>>) -> String {
         let mut skim_string = String::new();
 
+        // Get longest hostname length
+        let longest_hostname_length = self
+            .iter()
+            .map(|node| node.spec.hostname.len())
+            .max()
+            .unwrap_or(0);
+
         // sort nodes by hostname reverse
         let mut nodes = self;
         nodes.sort_by(|a, b| b.spec.hostname.cmp(&a.spec.hostname));
@@ -47,7 +54,13 @@ impl SkimString for Vec<Node> {
                 }
             }
 
-            skim_string += format!("{}\t{}\n", node.spec.hostname, label_string,).as_str();
+            skim_string += format!(
+                "{:<width$} {}\n",
+                node.spec.hostname,
+                label_string,
+                width = longest_hostname_length + 15
+            )
+            .as_str();
         }
 
         skim_string
